Handle

Struct Handle 

pub struct Handle<T> { /* private fields */ }
Resource entry wrapper.

Resources created by the resource_table! macro are wrapped in this struct, and it dereferences to the original type. This is an implementation detail to prevent Rust from aggressively optimizing away memory reads.